#ifndef HIGHLIGHTER_H
#define HIGHLIGHTER_H

#include <QSyntaxHighlighter>
#include <QTextDocument>
#include <QString>
#include <QVector>
#include <QRegExp>
#include <QTextCharFormat>
#include <QDomDocument>
#include <QHash>

class Highlighter : public QSyntaxHighlighter
{
public:
    explicit Highlighter(QString, QObject *parent = 0);
    bool setExtension(const QString&);

    void highlightBlock(const QString&) override;

private:
    QString xml_filename;
    QRegExp current_extension;

    struct HighlightingRule
    {
        QRegExp pattern;
        QTextCharFormat format;
    };

    struct HighlightLanguage
    {
        QVector <HighlightingRule> highlightingRules;

        QRegExp commentStartExpression;
        QRegExp commentEndExpression;

        QTextCharFormat keywordFormat;
        QTextCharFormat classFormat;
        QTextCharFormat singleLineCommentFormat;
        QTextCharFormat multiLineCommentFormat;
        QTextCharFormat quotationFormat;
        QTextCharFormat functionFormat;
        QTextCharFormat preprocFormat;
    };

    QHash<QRegExp, HighlightLanguage> languagesContainer;
};

#endif // HIGHLIGHTER_H